#include <iostream>

#include <boost/units/unit.hpp>
#include <boost/units/quantity.hpp>
#include <boost/units/systems/si.hpp>
#include <boost/units/systems/si/prefixes.hpp>
#include <boost/units/io.hpp>
#include <boost/units/base_units/metric/angstrom.hpp>

using namespace boost::units;
using namespace boost::units::si;

typedef quantity<si::length, double> length_type;

typedef make_scaled_unit <si::length,scale<10,static_rational<-3> > >::type millimeter;
typedef make_scaled_unit <si::length,scale<10,static_rational<-6> > >::type micrometer;
typedef make_scaled_unit <si::length,scale<10,static_rational<-9> > >::type nanometer;

namespace boost { namespace units
{
  typedef metric::angstrom_base_unit::unit_type angstrom_unit;
  BOOST_UNITS_STATIC_CONSTANT(angstrom, angstrom_unit);
  }
}

int
main (void)
{
  length_type x1(24.25 * micro * meter);
  //  length_type x2(2.0 * mm);
  quantity<micrometer> x2(24.25 * micro * meter);
  quantity<nanometer> x3(2.425 * angstrom);
  length_type x4(x2);

  std::cout << "Length x1 = " << x1 << std::endl;
  std::cout << "Length x2 = " << x2 << std::endl;
  std::cout << "Length x3 = " << x3 << std::endl;
  std::cout << "Length x4 = " << x4 << std::endl;

}
